@@ -38,19 +38,20 @@
 #'   \code{formula}.
 #'
 #' @details This stat can be used to automatically highlight residuals as
-#'   segments in a plot of a fitted model equation. This stat only generates the
-#'   residuals, the predicted values need to be separately added to the plot, so
-#'   to make sure that the same model formula is used in all steps it is best to
-#'   save the formula as an object and supply this object as argument to the
-#'   different statistics.
+#'   segments in a plot of a fitted model equation. This stat only returns the
+#'   fitted values and observations, the prediction and its confidence need to
+#'   be separately added to the plot when desired. Thus, to make sure that the
+#'   same model formula is used in all plot layers, it is best to save the
+#'   formula as an object and supply this object as argument to the different
+#'   statistics.
 #'
 #'   A ggplot statistic receives as data a data frame that is not the one passed
 #'   as argument by the user, but instead a data frame with the variables mapped
-#'   to aesthetics. In other words, it respects the grammar of graphics and
-#'   consequently within the model \code{formula} names of aesthetics like $x$
-#'   and $y$ should be used instead of the original variable names. This helps
-#'   ensure that the model is fitted to the same data as plotted in other
-#'   layers.
+#'   to aesthetics and NA values removed. In other words, it respects the
+#'   grammar of graphics and consequently within the model \code{formula} names
+#'   of aesthetics like $x$ and $y$ should be used instead of the original
+#'   variable names. This helps ensure that the model is fitted to the same data
+#'   as plotted in other layers.
 #'
 #' @note In the case of \code{method = "rq"} quantiles are fixed at \code{tau =
 #'   0.5} unless \code{method.args} has length > 0. Parameter \code{orientation}
@@ -61,7 +62,12 @@
 #'   as subset for each group containing five numeric variables. \describe{
 #'   \item{x}{x coordinates of observations} \item{x.fitted}{x coordinates of
 #'   fitted values} \item{y}{y coordinates of observations} \item{y.fitted}{y
-#'   coordinates of fitted values}}
+#'   coordinates of fitted values}, \item{weights}{the weights
+#'   passed as input to \code{lm()}, \code{rlm()}, or \code{lmrob()},
+#'   using aesthetic weight. More generally the value returned by
+#'   \code{weights()} }, \item{robustness.weights}{the "weights"
+#'   of the applied minimization criterion relative to those of OLS in
+#'   \code{rlm()}, or \code{lmrob()}} }
 #'
 #'   To explore the values returned by this statistic we suggest the use of
 #'   \code{\link[gginnards]{geom_debug}}. An example is shown below, where one
@@ -184,11 +190,25 @@ stat_fit_deviations <- function(mapping = NULL,
                                 orientation = NA,
                                 show.legend = FALSE,
                                 inherit.aes = TRUE) {
+
+  if (is.character(method)) {
+    method <- trimws(method, which = "both")
+    method.name <- method
+  } else if (is.function(method)) {
+    method.name <- deparse(substitute(method))
+    if (grepl("^function[ ]*[(]", method.name[1])) {
+      method.name <- "function"
+    }
+  } else {
+    method.name <- "missing"
+  }
+
   ggplot2::layer(
     stat = StatFitDeviations, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
     params =
       rlang::list2(method = method,
+                   method.name = method.name,
                    method.args = method.args,
                    n.min = n.min,
                    formula = formula,
@@ -207,7 +227,8 @@ stat_fit_deviations <- function(mapping = NULL,
 #'
 deviations_compute_group_fun <- function(data,
                                          scales,
-                                         method = "lm",
+                                         method,
+                                         method.name,
                                          method.args = list(),
                                          n.min = 2L,
                                          formula = y ~ x,
@@ -251,6 +272,7 @@ deviations_compute_group_fun <- function(data,
                      rlm = "rlm:M",
                      lqs = "lqs:lts",
                      rq = "rq:br",
+                     gls = "gls:REML",
                      method)
     method.name <- method
     method <- strsplit(x = method, split = ":", fixed = TRUE)[[1]]
@@ -266,24 +288,32 @@ deviations_compute_group_fun <- function(data,
                      rlm = MASS::rlm,
                      lqs = MASS::lqs,
                      rq = quantreg::rq,
+                     gls = nlme::gls,
                      match.fun(method))
   } else if (is.function(method)) {
     fun.method <- character()
-    if (is.name(quote(method))) {
-      method.name <- as.character(quote(method))
-    } else {
-      method.name <- "function"
-    }
   }
 
-  fun.args <- list(quote(formula),
-                   data = quote(data),
-                   weights = data[["weight"]])
+  if (exists("weight", data) && !all(data[["weight"]] == 1)) {
+    stopifnot("A mapping to 'weight' and a named argument 'weights' cannot co-exist" =
+                !"weights" %in% method.args)
+    fun.args <- list(formula = quote(formula),
+                     data = quote(data),
+                     weights = data[["weight"]])
+  } else {
+    fun.args <- list(formula = quote(formula),
+                     data = quote(data))
+  }
   fun.args <- c(fun.args, method.args)
   if (length(fun.method)) {
     fun.args[["method"]] <- fun.method
   }
 
+  # gls() parameter for formula is called model
+  if (grepl("gls", method.name)) {
+    names(fun.args)[1] <- "model"
+  }
+
   # quantreg contains code with partial matching of names!
   # so we silence selectively only these warnings
   withCallingHandlers({
@@ -295,21 +325,54 @@ deviations_compute_group_fun <- function(data,
     }
   })
 
-  fitted.vals <- stats::fitted(fm)
-  if (exists("w", fm)) {
-    weight.vals <- fm[["w"]]
-  } else {
-    weight.vals <- stats::weights(fm)
-    weight.vals <- ifelse(length(weight.vals) == length(fitted.vals),
-                          weight.vals,
-                          rep_len(NA_real_, length(fitted.vals)))
+  # As users may use model fit functions that we have not tested
+  # we try hard to extract the components from the model fit object
+  try(fitted.vals <- stats::fitted(fm))
+  if (inherits(fitted.vals, "try-error")) {
+    if (exists("fitted.values", fm) &&  # defensive
+        length(fm[["fitted.values"]]) == nrow(data)) {
+      fitted.vals <- fm[["fitted.values"]]
+    } else {
+      warning("Fitted values could not be retrieved!")
+      fitted.vals <- rep(NA_real_, nrow(data))
+    }
   }
+
+  if (inherits(fm, "lmrob")) {
+    rob.weight.vals <- stats::weights(fm, type = "robustness")
+    weight.vals <- stats::weights(fm, type = "prior")
+    if (!length(weight.vals)) {
+      weight.vals <- rep_len(1, nrow(data))
+    }
+  } else if (inherits(fm, "lts")) {
+    rob.weight.vals <- fm[["lts.wt"]]
+    weight.vals <- rep_len(1, nrow(data))
+  } else if (inherits(fm, "rlm")) {
+    rob.weight.vals <- fm[["w"]]
+    weight.vals <- stats::weights(fm)
+  } else if (inherits(fm, "lqs")) {
+    rob.weight.vals <- rep_len(NA_real_, nrow(data))
+    weight.vals <- rep_len(1, nrow(data))
+  } else {
+    rob.weight.vals <- rep(NA_real_, nrow(data))
+    try(prior.weight.vals <- stats::weights(fm))
+    if (inherits(weight.vals, "try-error")) {
+      if (exists("weights", fm) &&  # defensive
+          length(fm[["weights"]]) == nrow(data)) {
+        weight.vals <- fm[["weights"]]
+      } else {
+        weight.vals <- rep_len(NA_real_, nrow(data))
+      }
+    }
+  }
+
   if (orientation == "y") {
     data.frame(x = data$x,
                y = data$y,
                x.fitted = fitted.vals,
                y.fitted = data$y,
                weights = weight.vals,
+               robustness.weights = rob.weight.vals,
                hjust = 0)
   } else {
     data.frame(x = data$x,
@@ -317,6 +380,7 @@ deviations_compute_group_fun <- function(data,
                x.fitted = data$x,
                y.fitted = fitted.vals,
                weights = weight.vals,
+               robustness.weights = rob.weight.vals,
                hjust = 0)
   }
 }
@@ -349,11 +413,25 @@ stat_fit_fitted <- function(mapping = NULL, data = NULL, geom = "point",
                             orientation = NA,
                             show.legend = FALSE,
                             inherit.aes = TRUE, ...) {
+
+  if (is.character(method)) {
+    method <- trimws(method, which = "both")
+    method.name <- method
+  } else if (is.function(method)) {
+    method.name <- deparse(substitute(method))
+    if (grepl("^function[ ]*[(]", method.name[1])) {
+      method.name <- "function"
+    }
+  } else {
+    method.name <- "missing"
+  }
+
   ggplot2::layer(
     stat = StatFitFitted, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
     params =
       rlang::list2(method = method,
+                   method.name = method.name,
                    method.args = method.args,
                    n.min = n.min,
                    formula = formula,
@@ -373,6 +451,7 @@ stat_fit_fitted <- function(mapping = NULL, data = NULL, geom = "point",
 fitted_compute_group_fun <- function(data,
                                      scales,
                                      method,
+                                     method.name,
                                      method.args,
                                      n.min,
                                      formula,
@@ -416,6 +495,7 @@ fitted_compute_group_fun <- function(data,
                      rlm = "rlm:M",
                      lqs = "lqs:lts",
                      rq = "rq:br",
+                     gls = "gls:REML",
                      method)
     method.name <- method
     method <- strsplit(x = method, split = ":", fixed = TRUE)[[1]]
@@ -434,24 +514,32 @@ fitted_compute_group_fun <- function(data,
                      rlm = MASS::rlm,
                      lqs = MASS::lqs,
                      rq = quantreg::rq,
+                     gls = nlme::gls,
                      match.fun(method))
   } else if (is.function(method)) {
     fun.method <- character()
-    if (is.name(quote(method))) {
-      method.name <- as.character(quote(method))
-    } else {
-      method.name <- "function"
-    }
   }
 
-  fun.args <- list(quote(formula),
-                   data = quote(data),
-                   weights = data[["weight"]])
+  if (exists("weight", data) && !all(data[["weight"]] == 1)) {
+    stopifnot("A mapping to 'weight' and a named argument 'weights' cannot co-exist" =
+                !"weights" %in% method.args)
+    fun.args <- list(formula = quote(formula),
+                     data = quote(data),
+                     weights = data[["weight"]])
+  } else {
+    fun.args <- list(formula = quote(formula),
+                     data = quote(data))
+  }
   fun.args <- c(fun.args, method.args)
   if (length(fun.method)) {
     fun.args[["method"]] <- fun.method
   }
 
+  # gls() parameter for formula is called model
+  if (grepl("gls", method.name)) {
+    names(fun.args)[1] <- "model"
+  }
+
   # quantreg contains code with partial matching of names!
   # so we silence selectively only these warnings
   withCallingHandlers({
@@ -463,7 +551,19 @@ fitted_compute_group_fun <- function(data,
     }
   })
 
-  fitted.vals <- stats::fitted(fm)
+  # As users may use model fit functions that we have not tested
+  # we try hard to extract the components from the model fit object
+  try(fitted.vals <- stats::fitted(fm))
+  if (inherits(fitted.vals, "try-error")) {
+    if (exists("fitted.values", fm) &&  # defensive
+        length(fm[["fitted.values"]]) == nrow(data)) {
+      fitted.vals <- fm[["fitted.values"]]
+    } else {
+      warning("Fitted values could not be retrieved!")
+      fitted.vals <- rep(NA_real_, nrow(data))
+    }
+  }
+
   if (orientation == "y") {
     data.frame(x = fitted.vals,
                y = data$y)
