@@ -2,6 +2,20 @@ context("stat_poly_eq")
 
 library(tibble)
 
+# versioning of snaps
+ggplot2_version <- packageVersion("ggplot2")
+if (grepl("^3\\.5\\.2\\.9|^4\\.0\\.[0-1]", ggplot2_version)) {
+  ggplot2_version <- "gg-4.0.x"
+} else if (grepl("^3\\.5\\.[0-2]", ggplot2_version)) {
+  ggplot2_version <- "gg-3.5.x"
+} else {
+  ggplot2_version <- paste("gg", ggplot2_version, sep = "-")
+}
+R_version <- paste("R",
+                   substr(as.character(getRversion()), start = 1, stop = 3),
+                   sep = "-")
+snap_version <- paste(R_version, ggplot2_version, sep = "_")
+
 old.out.dec <- options(OutDec = ".")
 on.exit(options(old.out.dec), add = TRUE, after = FALSE)
 
@@ -30,7 +44,8 @@ test_that("poly_eq_noload", {
                                                         ggplot2::aes(label = paste(ggplot2::after_stat(eq.label),
                                                                                    ggplot2::after_stat(AIC.label),
                                                                                    ggplot2::after_stat(BIC.label),
-                                                                                   sep = "~~")))
+                                                                                   sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_noload_more",
@@ -45,21 +60,24 @@ test_that("poly_eq_noload", {
                                                                                    ggplot2::after_stat(p.value.label),
                                                                                    ggplot2::after_stat(n.label),
                                                                                    ggplot2::after_stat(method.label),
-                                                                                   sep = "~~")))
+                                                                                   sep = "~~"))),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_noload_use_label",
                               ggplot2::ggplot(my.data, ggplot2::aes(x, y)) +
                                 ggplot2::geom_point() +
                                 ggpmisc::stat_poly_eq(formula = y ~ x, parse = TRUE,
                                                       mapping = ggpmisc::use_label(c("eq", "AIC", "BIC"),
-                                                                                   sep = "~~"))
+                                                                                   sep = "~~")),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_noload_use_label_more",
                               ggplot2::ggplot(my.data, ggplot2::aes(x, y)) +
                                 ggplot2::geom_point() +
                                 ggpmisc::stat_poly_eq(formula = y ~ x, parse = TRUE,
                                                       mapping = ggpmisc::use_label(c("R2", "R2.CI", "adj.R2", "F", "P"),
-                                                                                   sep = "~~"))
+                                                                                   sep = "~~")),
+                              variant = snap_version
   )
 })
 
@@ -289,7 +307,8 @@ test_that("poly_formulas", {
                                                     after_stat(adj.rr.label),
                                                     after_stat(AIC.label),
                                                     after_stat(BIC.label),
-                                                    sep = "~~")))
+                                                    sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_1a",
@@ -303,7 +322,8 @@ test_that("poly_formulas", {
                                                                  after_stat(p.value.label),
                                                                  after_stat(n.label),
                                                                  after_stat(method.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_x",
@@ -315,7 +335,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_x_Iy",
@@ -327,7 +348,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_x_Ix",
@@ -339,7 +361,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_xminus1",
@@ -351,7 +374,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_xminus1a",
@@ -363,7 +387,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_xminus1b",
@@ -375,7 +400,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_xplus0",
@@ -387,7 +413,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_xplus0a",
@@ -399,7 +426,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_xplus0b",
@@ -411,7 +439,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_poly1",
@@ -423,7 +452,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_poly3",
@@ -435,7 +465,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_x1",
@@ -447,7 +478,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(AIC.label),
                                                                  after_stat(BIC.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_y",
@@ -459,7 +491,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_yminus1",
@@ -471,7 +504,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_yplus0",
@@ -483,7 +517,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_ypoly1",
@@ -495,7 +530,8 @@ test_that("poly_formulas", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   old.out.dec <- options(OutDec = ",")
@@ -509,7 +545,8 @@ test_that("poly_formulas", {
                                                                  after_stat(rr.confint.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_more_comma",
                               ggplot2::ggplot(my.data, ggplot2::aes(x, y)) +
@@ -521,7 +558,8 @@ test_that("poly_formulas", {
                                                                                    after_stat(p.value.label),
                                                                                    after_stat(n.label),
                                                                                    after_stat(method.label),
-                                                                                   sep = "~~")))
+                                                                                   sep = "~~"))),
+                              variant = snap_version
   )
   options(old.out.dec)
 })
@@ -541,7 +579,8 @@ test_that("poly_methods", {
                                                                  after_stat(n.label),
                                                                  after_stat(AIC.label),
                                                                  after_stat(BIC.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_lm_fun",
@@ -558,7 +597,8 @@ test_that("poly_methods", {
                                                                  after_stat(n.label),
                                                                  after_stat(AIC.label),
                                                                  after_stat(BIC.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_rlm_chr",
@@ -575,7 +615,8 @@ test_that("poly_methods", {
                                                                  after_stat(n.label),
                                                                  after_stat(AIC.label),
                                                                  after_stat(BIC.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_rlm_fun",
@@ -592,7 +633,80 @@ test_that("poly_methods", {
                                                                  after_stat(n.label),
                                                                  after_stat(AIC.label),
                                                                  after_stat(BIC.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
+  )
+
+  vdiffr::expect_doppelganger("stat_poly_eq_lqs_chr",
+                              ggplot(my.data, aes(x, y)) +
+                                geom_point() +
+                                stat_poly_eq(formula = y ~ x, parse = TRUE,
+                                             method = "lqs",
+                                             mapping =
+                                               aes(label = paste(after_stat(eq.label),
+                                                                 after_stat(rr.label),
+                                                                 after_stat(adj.rr.label),
+                                                                 after_stat(f.value.label),
+                                                                 after_stat(p.value.label),
+                                                                 after_stat(n.label),
+                                                                 after_stat(AIC.label),
+                                                                 after_stat(BIC.label),
+                                                                 sep = "~~"))),
+                              variant = snap_version
+  )
+
+  vdiffr::expect_doppelganger("stat_poly_eq_lqs_fun",
+                              ggplot(my.data, aes(x, y)) +
+                                geom_point() +
+                                stat_poly_eq(formula = y ~ x, parse = TRUE,
+                                             method = MASS::lqs,
+                                             mapping =
+                                               aes(label = paste(after_stat(eq.label),
+                                                                 after_stat(rr.label),
+                                                                 after_stat(adj.rr.label),
+                                                                 after_stat(f.value.label),
+                                                                 after_stat(p.value.label),
+                                                                 after_stat(n.label),
+                                                                 after_stat(AIC.label),
+                                                                 after_stat(BIC.label),
+                                                                 sep = "~~"))),
+                              variant = snap_version
+  )
+
+  vdiffr::expect_doppelganger("stat_poly_eq_gls_chr",
+                              ggplot(my.data, aes(x, y)) +
+                                geom_point() +
+                                stat_poly_eq(formula = y ~ x, parse = TRUE,
+                                             method = "gls",
+                                             mapping =
+                                               aes(label = paste(after_stat(eq.label),
+                                                                 after_stat(rr.label),
+                                                                 after_stat(adj.rr.label),
+                                                                 after_stat(f.value.label),
+                                                                 after_stat(p.value.label),
+                                                                 after_stat(n.label),
+                                                                 after_stat(AIC.label),
+                                                                 after_stat(BIC.label),
+                                                                 sep = "~~"))),
+                              variant = snap_version
+  )
+
+  vdiffr::expect_doppelganger("stat_poly_eq_gls_fun",
+                              ggplot(my.data, aes(x, y)) +
+                                geom_point() +
+                                stat_poly_eq(formula = y ~ x, parse = TRUE,
+                                             method = nlme::gls,
+                                             mapping =
+                                               aes(label = paste(after_stat(eq.label),
+                                                                 after_stat(rr.label),
+                                                                 after_stat(adj.rr.label),
+                                                                 after_stat(f.value.label),
+                                                                 after_stat(p.value.label),
+                                                                 after_stat(n.label),
+                                                                 after_stat(AIC.label),
+                                                                 after_stat(BIC.label),
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_missing_fm",
@@ -616,6 +730,43 @@ test_that("poly_methods", {
                                              method = function(...) {NA})
   )
 
+  skip_if_not_installed("robustbase", minimum_version = NULL)
+  vdiffr::expect_doppelganger("stat_poly_eq_lmrob_fun",
+                              ggplot(my.data, aes(x, y)) +
+                                geom_point() +
+                                stat_poly_eq(formula = y ~ x, parse = TRUE,
+                                             method = robustbase::lmrob,
+                                             mapping =
+                                               aes(label = paste(after_stat(eq.label),
+                                                                 after_stat(rr.label),
+                                                                 after_stat(adj.rr.label),
+                                                                 after_stat(f.value.label),
+                                                                 after_stat(p.value.label),
+                                                                 after_stat(n.label),
+                                                                 after_stat(AIC.label),
+                                                                 after_stat(BIC.label),
+                                                                 sep = "~~"))),
+                              variant = snap_version
+  )
+
+  vdiffr::expect_doppelganger("stat_poly_eq_ltsReg_fun",
+                              ggplot(my.data, aes(x, y)) +
+                                geom_point() +
+                                stat_poly_eq(formula = y ~ x, parse = TRUE,
+                                             method = robustbase::ltsReg,
+                                             mapping =
+                                               aes(label = paste(after_stat(eq.label),
+                                                                 after_stat(rr.label),
+                                                                 after_stat(adj.rr.label),
+                                                                 after_stat(f.value.label),
+                                                                 after_stat(p.value.label),
+                                                                 after_stat(n.label),
+                                                                 after_stat(AIC.label),
+                                                                 after_stat(BIC.label),
+                                                                 sep = "~~"))),
+                              variant = snap_version
+  )
+
 })
 
 test_that("textual_positions", {
@@ -623,35 +774,40 @@ test_that("textual_positions", {
                               ggplot(my.data, aes(x, y)) +
                                 geom_point() +
                                 stat_smooth(method = "lm", formula = formula) +
-                                stat_poly_eq(formula = formula, parse = TRUE)
+                                stat_poly_eq(formula = formula, parse = TRUE),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_1",
                                ggplot(my.data, aes(x, y)) +
                                 geom_point() +
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
-                                             geom = "text_npc")
+                                             geom = "text_npc"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_2",
                               ggplot(my.data, aes(x, y)) +
                                 geom_point() +
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
-                                             geom = "label_npc")
+                                             geom = "label_npc"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_3",
                               ggplot(my.data, aes(x, y)) +
                                 geom_point() +
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
-                                             geom = "text")
+                                             geom = "text"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_4",
                               ggplot(my.data, aes(x, y)) +
                                 geom_point() +
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
-                                             geom = "label")
+                                             geom = "label"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_5",
                               ggplot(my.data, aes(x, y)) +
@@ -659,7 +815,8 @@ test_that("textual_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = "right", label.y = "bottom",
-                                             geom = "text_npc")
+                                             geom = "text_npc"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_6",
                               ggplot(my.data, aes(x, y)) +
@@ -667,7 +824,8 @@ test_that("textual_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = "right", label.y = "bottom",
-                                             geom = "label_npc")
+                                             geom = "label_npc"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_7",
                               ggplot(my.data, aes(x, y)) +
@@ -675,7 +833,8 @@ test_that("textual_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = "right", label.y = "bottom",
-                                             geom = "text")
+                                             geom = "text"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_8",
                               ggplot(my.data, aes(x, y)) +
@@ -683,7 +842,8 @@ test_that("textual_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = "right", label.y = "bottom",
-                                             geom = "label")
+                                             geom = "label"),
+                              variant = snap_version
   )
 })
 
@@ -694,7 +854,8 @@ test_that("numeric_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = 0, label.y = 0,
-                                             geom = "text_npc")
+                                             geom = "text_npc"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_n2",
                               ggplot(my.data, aes(x, y)) +
@@ -702,7 +863,8 @@ test_that("numeric_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = 0, label.y = 0,
-                                             geom = "label_npc")
+                                             geom = "label_npc"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_n3",
                               ggplot(my.data, aes(x, y)) +
@@ -710,7 +872,8 @@ test_that("numeric_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = 0, label.y = -1e5,
-                                             geom = "text")
+                                             geom = "text"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_n4",
                               ggplot(my.data, aes(x, y)) +
@@ -718,7 +881,8 @@ test_that("numeric_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = 0, label.y = -1e5,
-                                             geom = "label")
+                                             geom = "label"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_n5",
                               ggplot(my.data, aes(x, y)) +
@@ -726,7 +890,8 @@ test_that("numeric_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = 1, label.y = 0.5,
-                                             geom = "text_npc")
+                                             geom = "text_npc"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_n6",
                               ggplot(my.data, aes(x, y)) +
@@ -734,7 +899,8 @@ test_that("numeric_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = 1, label.y = 0.5,
-                                             geom = "label_npc")
+                                             geom = "label_npc"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_n7",
                               ggplot(my.data, aes(x, y)) +
@@ -742,7 +908,8 @@ test_that("numeric_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = 100, label.y = 5e5,
-                                             geom = "text")
+                                             geom = "text"),
+                              variant = snap_version
   )
   vdiffr::expect_doppelganger("stat_poly_eq_n8",
                               ggplot(my.data, aes(x, y)) +
@@ -750,7 +917,8 @@ test_that("numeric_positions", {
                                 stat_smooth(method = "lm", formula = formula) +
                                 stat_poly_eq(formula = formula, parse = TRUE,
                                              label.x = 100, label.y = 5e5,
-                                             geom = "label")
+                                             geom = "label"),
+                              variant = snap_version
   )
 })
 
@@ -769,7 +937,8 @@ test_that("rounding_signif", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_1_round",
@@ -786,7 +955,8 @@ test_that("rounding_signif", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
   vdiffr::expect_doppelganger("stat_poly_eq_formula_x_round_Inf",
@@ -803,7 +973,8 @@ test_that("rounding_signif", {
                                                                  after_stat(adj.rr.label),
                                                                  after_stat(f.value.label),
                                                                  after_stat(p.value.label),
-                                                                 sep = "~~")))
+                                                                 sep = "~~"))),
+                              variant = snap_version
   )
 
 })
@@ -821,7 +992,8 @@ if (requireNamespace("ggtext", quietly = TRUE)) {
                                   stat_poly_eq(geom = "richtext",
                                                formula = formula,
                                                hjust = 0, vjust = 1,
-                                               label.x = 0, label.y = 10e5)
+                                               label.x = 0, label.y = 10e5),
+                                variant = snap_version
     )
     vdiffr::expect_doppelganger("stat_poly_eq_n2_markdown",
                                 ggplot(my.data, aes(x, y)) +
@@ -831,7 +1003,8 @@ if (requireNamespace("ggtext", quietly = TRUE)) {
                                                geom = "richtext",
                                                formula = formula,
                                                hjust = 0, vjust = 1,
-                                               label.x = 0, label.y = 10e5)
+                                               label.x = 0, label.y = 10e5),
+                                variant = snap_version
     )
     vdiffr::expect_doppelganger("stat_poly_eq_n3_markdown",
                                 ggplot(my.data, aes(x, y)) +
@@ -842,7 +1015,8 @@ if (requireNamespace("ggtext", quietly = TRUE)) {
                                                geom = "richtext",
                                                formula = formula,
                                                hjust = 0, vjust = 1,
-                                               label.x = 0, label.y = 10e5)
+                                               label.x = 0, label.y = 10e5),
+                                variant = snap_version
     )
     vdiffr::expect_doppelganger("stat_poly_eq_n4_markdown",
                                 ggplot(my.data, aes(x, y)) +
@@ -852,7 +1026,8 @@ if (requireNamespace("ggtext", quietly = TRUE)) {
                                                geom = "richtext",
                                                formula = formula,
                                                hjust = 0, vjust = 1,
-                                               label.x = 0, label.y = 10e5)
+                                               label.x = 0, label.y = 10e5),
+                                variant = snap_version
     )
   })
 }
